==> geo-0.16-sources.jar: boofcv/abst/geo/BundleAdjustmentCalibrated.java <==
/*
 * Copyright (c) 2011-2013, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.abst.geo;

import boofcv.alg.geo.bundle.CalibratedPoseAndPoint;
import boofcv.alg.geo.bundle.ViewPointObservations;

import java.util.List;

/**
 * Interface for performing bundle adjustment on data when the camera calibration is
 * assumed to be known and fixed.  Bundle adjustment will optimize both the cameras
 * extrinsic parameters and the world's structure (point locations) at the same
 * time.
 *
 * @author Peter Abeles
 */
public interface BundleAdjustmentCalibrated {

	/**
	 * Refines the parameter estimated using bundle adjustment.
	 *
	 * @param initialModel Initial estimate at parameters.  Modified on output with refined results.
	 * @param observations Observation of image features in each frame. Normalized coordinates.
	 * @return true if successful
	 */
	public boolean process( CalibratedPoseAndPoint initialModel ,
							List<ViewPointObservations> observations );
}

==> geo-0.18-sources.jar: boofcv/abst/geo/BundleAdjustmentCalibrated.java <==
/*
 * Copyright (c) 2011-2014, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.abst.geo;

import boofcv.alg.geo.bundle.CalibratedPoseAndPoint;
import boofcv.alg.geo.bundle.ViewPointObservations;

import java.util.List;

/**
 * Interface for performing bundle adjustment on data when the camera calibration is
 * assumed to be known and fixed.  Bundle adjustment will optimize both the cameras
 * extrinsic parameters and the world's structure (point locations) at the same
 * time.
 *
 * @author Peter Abeles
 */
public interface BundleAdjustmentCalibrated {

	/**
	 * Refines the parameter estimated using bundle adjustment.
	 *
	 * @param initialModel Initial estimate at parameters.  Modified on output with refined results.
	 * @param observations Observation of image features in each frame. Normalized coordinates.
	 * @return true if successful or false if it failed
	 */
	public boolean process( CalibratedPoseAndPoint initialModel ,
							List<ViewPointObservations> observations );
}
